@@ -1,6 +1,6 @@
 use quote::{quote, ToTokens};
 
-use crate::html::{attributes::Attributes, children::Children};
+use crate::html::{attributes::Attributes, children::Children, tag_name::TagName};
 
 use super::{HtmlCustomElement, HtmlPartial, Node};
 
@@ -8,7 +8,7 @@ use super::{HtmlCustomElement, HtmlPartial, Node};
 pub struct HtmlElement {
   pub attributes: Attributes,
   pub children: Children,
-  pub name: syn::Ident,
+  pub name: TagName,
 }
 
 impl From<HtmlElement> for Node {
@@ -44,13 +44,13 @@ impl ToTokens for HtmlElement {
   fn to_tokens(&self, tokens: &mut proc_macro2::TokenStream) {
     let attributes = &self.attributes;
     let children = &self.children;
-    let name = &self.name;
+    let name = &self.name.to_string();
 
     let element = quote!(
       ahecha::html::Node::Element(ahecha::html::Element {
         attributes: #attributes,
         children: #children,
-        name: stringify!(#name),
+        name: #name,
       })
     );
     element.to_tokens(tokens);
